#******************************************************************************
#**** Copyright (C) 2009, 2010                                             ****
#****   John Schneiderman <JohnMS@member.fsf.org>                          ****
#****                                                                      ****
#**** This program is free software: you can redistribute it and/or modify ****
#**** it under the terms of the GNU General Public License as published by ****
#**** the Free Software Foundation, either version 3 of the License, or    ****
#**** (at your option) any later version.                                  ****
#****                                                                      ****
#**** This program is distributed in the hope that it will be useful,      ****
#**** but WITHOUT ANY WARRANTY; without even the implied warranty of       ****
#**** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        ****
#**** GNU General Public License for more details.                         ****
#****                                                                      ****
#**** You should have received a copy of the GNU General Public License    ****
#**** along with this program.  If not, see <http://www.gnu.org/licenses/> ****
#******************************************************************************


# Files to include when creating the Kap package.
__all__ =   [   "kap.py",
                "kapdialogue.py",
                "medialibrarydialogue.py",
                "medialibrary.py",
                "medialibrarythread.py",
                "mediaparser.py",
                "mediasong.py",
                "mediasongdataobject.py",
                "mediasongdroptarget.py",
                "mplayerplayer.py",
                "mplayersignal.py",
                "playerbase.py",
                "playercontroller.py",
                "playerfactory.py",
                "playersignal.py",
                "playerthread.py",
                "playerwindow.py",
                "playlistwindow.py",
                "searchwindow.py"
            ]
